@@ -126,9 +126,14 @@ class BaseConnection:
         self._last_sent = time.time()  # prevents from sending too rapidly
         self._last_rcv = (0.0, None) # stores the data that the user previously received
 
+        # IO variables
         self._rcv_queue = []  # stores previous received strings and timestamps, tuple (timestamp, str)
         self._to_send = [] # queue data to send
 
+        # this lock makes sure data from the receive queue
+        # and send queue are written to and read safely
+        self._lock = threading.Lock()
+
     def __repr__(self) -> str:
         """
         Returns string representation of self
@@ -190,7 +195,9 @@ class BaseConnection:
     def disconnect(self) -> None:
         """Closes connection to the serial port.
 
-        When called, calls `Serial.close()` then makes the connection `None`. If it is currently closed then just returns.
+        When called, calls `Serial.close()` then makes the connection `None`. 
+        If it is currently closed then just returns.
+        Forces the IO thread to close.
         
         **NOTE**: This method should be called if the object will not be used anymore
         or before the object goes out of scope, as deleting the object without calling 
@@ -270,9 +277,12 @@ class BaseConnection:
         # add ending to string
         send_data = (send_data + ending).encode("utf-8")
 
-        if (len(self._to_send) < 65536):
-            # only append if limit has not been reached
-            self._to_send.append(send_data)
+        # make sure nothing is reading/writing to the receive queue
+        # while reading/assigning the variable
+        with self._lock:
+            if (len(self._to_send) < 65536):
+                # only append if limit has not been reached
+                self._to_send.append(send_data)
         
         return True
 
@@ -317,8 +327,12 @@ class BaseConnection:
             return None
         
         try:
-            self._last_rcv = self._rcv_queue[-1-num_before] # last received data
-            return self._rcv_queue[-1-num_before]
+            # make sure nothing is reading/writing to the receive queue
+            # while reading/assigning the variable
+            with self._lock:
+                self._last_rcv = self._rcv_queue[-1-num_before] # last received data
+
+            return self._last_rcv
         except IndexError:
             return None
  
@@ -428,27 +442,39 @@ class BaseConnection:
 
         while (self._conn is not None):
             try:
+                # make sure other threads cannot read/write variables
+                # copy the variables to temporary ones so the locks don't block for so long
+                with self._lock:
+                    _rcv_queue = self._rcv_queue.copy()
+                    _send_queue = self._to_send.copy()
+
                 # keep on trying to poll data as long as connection is still alive
                 if (self._conn.in_waiting):
                     # read everything from serial buffer
                     incoming = self._conn.read_all()
 
                     # add to queue
-                    self._rcv_queue.append((time.time(), incoming)) # tuple (timestamp, str)
-                    if (len(self._rcv_queue) > self._queue_size):
+                    _rcv_queue.append((time.time(), incoming)) # tuple (timestamp, str)
+                    if (len(_rcv_queue) > self._queue_size):
                         # if greater than queue size, then pop first element
-                        self._rcv_queue.pop(0)
+                        _rcv_queue.pop(0)
 
                 # sending data (send one at a time in queue for 0.5 seconds)
                 st_t = time.time() # start time
                 while (time.time() - st_t < 0.5):
-                    if (len(self._to_send) > 0):
-                        self._conn.write(self._to_send.pop(0))
+                    if (len(_send_queue) > 0):
+                        self._conn.write(_send_queue.pop(0))
                         self._conn.flush()
                     else:
                         # break out if all sent
                         break
                     time.sleep(0.01)
+                
+                # make sure other threads cannot read/write variables
+                with self._lock:
+                    # copy the variables back
+                    self._rcv_queue = _rcv_queue.copy()
+                    self._to_send = _send_queue.copy()
 
                 time.sleep(0.01)  # rest CPU
             except (ConnectException, OSError, serial.SerialException):
